{% load static %}

<div class="title-page">
{% if data.custom_resource %}
<i class="fas {{data.custom_resource.icon}}" style="color: {{data.custom_resource.icon_color}};" aria-hidden="true"></i>
    Add a new {{data.custom_resource.title}}
{% else %}
Add a new Resource
{% endif %}
</div>

<br/>
<div id ="role_title" style="display: none;">
    {{data.custom_resource.title}}
</div>
<div class="alert alert-danger" id="banner_errors" style="display: none;">
        <button type="button" aria-label="Close"
            {% if BOOTSTRAP_VERSION|first == "4" %}class="close"
            {% elif BOOTSTRAP_VERSION|first == "5" %}class="btn-close float-end"
            {% endif %}
            {% if BOOTSTRAP_VERSION|first == "4" %}data-dismiss="alert"
            {% elif BOOTSTRAP_VERSION|first == "5" %}data-bs-dismiss="alert"
            {% endif %}
    >
            {% if BOOTSTRAP_VERSION|first == "4" %}
                <span aria-hidden="true">&times;</span>
            {% elif BOOTSTRAP_VERSION|first == "5" %}
            {% endif %}
        </button>
        <h4><i class="fas fa-exclamation-circle"></i> Error</h4>
        <div id="form_start_errors"></div>


</div>

Please select one of the following options to Add your Resource. You can create a new resource, or upload an XML file.

<br/><br/>
<div id="form_start_content">
</div>
<div id="template_id" class="hidden">{{ data.template_id }}</div>
<br/><br/>

<button id="btn-save-data" class="btn btn-primary" hidden=""><i class="fas fa-save"></i> Save without editing</button>
<button id="btn-open-data" class="btn btn-primary"><i class="fas fa-code"></i> Open in Text editor</button>
<button id="btn-display-data" class="btn btn-primary"><i class="fas fa-play"></i> Start editing</button>
<div id="role" class="hidden">{{ data.role }}</div>